<?php
session_start();

$language = $_SESSION['language'];
if (!$language){
    $language = "en";
    $_SESSION['language'] = "en";
}

require_once("../vars.php");
require_once("../includes/settings.class.php");
require_once("../includes/show.class.php");
require_once("../templates/smarty/libs/Smarty.class.php");
require_once("../language/$language/general.php");
require_once("../language/$language/tv_guide.php");

$settings = new Settings();

$global_settings = $settings->getMultiSettings(array("seo_links"), true);

if (!isset($global_settings['seo_links']) || !in_array($global_settings['seo_links'],array(0,1))){
    $seo_links = 1;
} else {
    $seo_links = $global_settings['seo_links'];
}

if (!isset($_SESSION['theme']) || !$_SESSION['theme']){
    $theme = $settings->getSetting("theme");
    if (!count($theme)){
        $theme = 'svarog';
    } else {
        $theme = $theme->theme;
    }
} else {
    $theme = $_SESSION['theme'];
}

$smarty = new Smarty();
$smarty->caching = 0;
$smarty->template_dir = "$basepath/templates/$theme";
$smarty->config_dir = "$basepath/templates/smarty/configs";
if (file_exists("$basepath/cachefiles/$theme")){
	$smarty->compile_dir = "$basepath/cachefiles/$theme";
	$smarty->cache_dir = "$basepath/cachefiles/$theme";
} else {
	$smarty->compile_dir = "$basepath/cachefiles/";
	$smarty->cache_dir = "$basepath/cachefiles";
}
$smarty->assign("templatepath","$baseurl/templates/$theme");

if (!isset($_REQUEST['date'])){
    $date = date("Y-m-d");
} else {
    $date = $_REQUEST['date'];
}

$check = date("Y",strtotime($date));
if ($check < 2010){
    $date = date("Y-m-d");
}

require_once("../vars.php");
require_once("../includes/curl.php");

$curl = new Curl();
$show = new Show();

$cache_file = "tv_guide_".$date.".txt";
$from_cache = false;

if (file_exists($basepath."/cachefiles/".$cache_file)){
    $data = file_get_contents($basepath."/cachefiles/".$cache_file);
    $from_cache = true;
} else {
    $request = "http://tv-api.com/api/?method=getTVguide&data=".urlencode(json_encode(array("date" => $date, "local_time" => date("Y-m-d H:i:s"))));
    $data = $curl->get($request);    
}

if ($from_cache || ($curl->getHttpCode()>=200 && $curl->getHttpCode()<400)){
    
    if (!$from_cache && is_writable($basepath."/cachefiles/")){
        @file_put_contents($basepath."/cachefiles/".$cache_file, $data);
    }
    
    $data = json_decode($data, true);
        
    if (isset($data['status']) && $data['status'] == "success" && isset($data['guide']) && isset($data['guide'][$date])){
        $events = $data['guide'][$date];
        foreach($events as $key => $event){
            $events[$key]['episode_number'] = str_replace(array("#season#","#episode#"), array(str_pad($event['season'],2, 0, STR_PAD_LEFT),str_pad($event['episode'],2, 0, STR_PAD_LEFT)),  $lang['tv_guide_episode_number']);            
            $show_data = $show->getShowByImdb($events[$key]['imdb_id'], $language);
            if (!count($show_data)){
                $events[$key]['show'] = $events[$key]['show_title'];
            } else {
                if ($seo_links){
                    $events[$key]['show'] = "<a href=\"$baseurl/".$routes['show']."/".$show_data['permalink']."\">".$show_data['title']."</a>";    
                } else {
                    $events[$key]['show'] = "<a href=\"$baseurl/index.php?menu=show&perma=".$show_data['permalink']."\">".$show_data['title']."</a>";
                }
                
                $episode_data = $show->getEpisode($show_data['id'], $event['season'], $event['episode']);
                if ($episode_data){
                    if ($seo_links){
                        $events[$key]['episode_number'] = "<a href=\"$baseurl/".$routes['show']."/".$show_data['permalink']."/season/".$event['season']."/episode/".$event['episode']."\">".$events[$key]['episode_number']."</a>";
                    } else {
                        $events[$key]['episode_number'] = "<a href=\"$baseurl/index.php?menu=episode&perma=".$show_data['permalink']."&season=".$event['season']."&episode=".$event['episode']."\">".$events[$key]['episode_number']."</a>";
                    }
                }
            }
        }
        
        $smarty->assign("events", $events);
    } else {
        $smarty->assign("events", array());
    }
    
} else {
    $smarty->assign("events", array());
}

if (isset($data['guide']['next_day'])){
    $smarty->assign("do_next_day", $data['guide']['next_day']);
} else {
    $smarty->assign("do_next_day", "no");
}

if (isset($data['guide']['prev_day'])){
    $smarty->assign("do_previous_day", $data['guide']['prev_day']);
} else {
    $smarty->assign("do_previous_day", "no");
}

if ($date == date("Y-m-d")){
    $title = $lang['tv_guide_todays_schedule'];
} elseif ($date == date("Y-m-d", strtotime("tomorrow"))){
    $title = $lang['tv_guide_tomorrows_schedule'];
} elseif ($date == date("Y-m-d", strtotime("yesterday"))){
    $title = $lang['tv_guide_yesterdays_schedule'];
} else {
    $title = str_replace("#date#", $date, $lang['tv_guide_dates_schedule']);
}
$smarty->assign("previous_day", date("Y-m-d",strtotime("-1 day", strtotime($date))));
$smarty->assign("next_day", date("Y-m-d",strtotime("+1 day", strtotime($date))));
$smarty->assign("server_timezone", date('T'));
$smarty->assign("title", $title);
$smarty->assign("date", $date);
$smarty->assign("lang", $lang);
$smarty->display("ajax_tv_guide.tpl");

?>