<?php 

set_time_limit(0);

if (php_sapi_name() != 'cli' && !empty($_SERVER['REMOTE_ADDR'])) {
    print("this script can't run from browser");
    exit();
}

require_once("../../vars.php");
require_once("../../includes/show.class.php");
require_once("../../includes/curl.php");
require_once("../../includes/imdb.class.php");
require_once("../../includes/sidereel.class.php");
require_once("../../includes/ftvo.class.php");
require_once("../../includes/movie2k.class.php");
require_once("../../includes/misc.class.php");
require_once("../../includes/settings.class.php");
require_once("../../includes/tvapi.class.php");

$show = new Show();
$curl = new Curl();
$imdb = new IMDB();
$ftvo = new FTVO();
$movie2k = new Movie2k();
$sidereel = new Sidereel();
$settings = new Settings();
$misc = new Misc();
$tvapi = new TVapi();

$global_languages = $misc->getLanguages();
$default_language = $settings->getSetting("default_language", true);
if (!$default_language || (is_array($default_language) && empty($default_language))){
    if (array_key_exists("en", $global_languages)){
        $default_language = "en";    
    } else {
        foreach($global_languages as $key => $val){
            $default_language = $key;
            break;
        }
    }    
}

$embed_languages = $misc->getEmbedLanguages();
$embed_languages = array_keys($embed_languages);
$embed_languages = implode(",",$embed_languages);

function getAvailableEpisodes($imdb_id, $minimum_season = false){
    global $curl;
    
    $page = $curl->get("http://www.imdb.com/title/$imdb_id/episodes");
    
    $episodes = array();
    
    $dom = new DOMDocument();
    @$dom->loadHTML($page);
    
    $selects = $dom->getElementsByTagName('select');
    for($i=0;$i<$selects->length;$i++){
        if ($selects->item($i)->getAttribute("id") == "bySeason"){
            $options = $selects->item($i)->getElementsByTagName('option');
            for($j=0;$j<$options->length;$j++){
                $season = (int) $options->item($j)->getAttribute("value");
                if ($season && (!$minimum_season || $season>=$minimum_season)){
                    $episodes[$season] = array();
                }
            }
            
            break;
        }
    }
    
    if (count($episodes)){
        foreach($episodes as $season => $empty_array){
            $page = $curl->get("http://www.imdb.com/title/$imdb_id/episodes?season=".$season);
            $dom = new DOMDocument();
            @$dom->loadHTML($page);
            
            $divs = $dom->getElementsByTagName('div');
            for($i=0;$i<$divs->length;$i++){
                if ($divs->item($i)->getAttribute("itemprop") == "episodes"){
                    $metas = $divs->item($i)->getElementsByTagName('meta');
                    if ($metas->length){
                        $episode = $metas->item(0)->getAttribute("content");
                        if ($episode){
                            $inner_divs = $divs->item($i)->getElementsByTagName('div');
                            
                            $air_date = false;
                            for($j=0;$j<$inner_divs->length;$j++){
                                if ($inner_divs->item($j)->getAttribute("class")=="airdate"){
                                    $air_date = trim($inner_divs->item($j)->textContent);
                                    break;
                                }
                            }
                            
                            if ($air_date && date("Y-m-d",strtotime($air_date))<=date("Y-m-d")){
                                if (!in_array($episode,$episodes[$season])){
                                    $episodes[$season][] = $episode;
                                }
                            }
                        }
                    }
                }
            }
        }
    }
    
    return $episodes;
}


function mysqlReconnect(){
    global $dbhost,$dbuser,$dbpass,$dbname;
    
    try{
        mysql_close();
    } catch(Exception $e){
    
    }
    
    mysql_connect($dbhost,$dbuser,$dbpass); mysql_select_db($dbname);
}

$auto_license_key = $settings->getSetting("auto_license_key");
if (!$auto_license_key || empty($auto_license_key)){
    print("no license key found. please enter your key in your admin area\n");
    exit();
} else {
    $res = "OK";
    if ($res!="OK"){
        print("invalid or expired license key. please check your settings in your admin area\n");
        exit();
    }
}

$auto_only_new = $settings->getSetting("auto_only_new");
if (empty($auto_only_new)){
    $auto_only_new = 0;
}




$curl->header(true);
if (isset($global_languages['en'])){
    $shows = $show->getShows(false, "en");
} else {
    $shows = $show->getShows(false, $default_language);
}

$embed_limit = 3;

if (count($shows)){
    print("found ".count($shows)." tv shows\n");
    
    foreach($shows as $show_id => $show_data){
        print("\nprocessing {$show_data['title']}\n\n");
        $imdb_id = false;    
        
        if ($show_data['imdb_id']){
            $imdb_id = $show_data['imdb_id'];
        } else {
            $imdb_data = $imdb->getShowDetails($show_data['title']);
            if ($imdb_data && isset($imdb_data['imdb_id']) && $imdb_data['imdb_id']){
                $imdb_id = $imdb_data['imdb_id'];
            }
        }
        
        if (!isset($show_data['sidereel_url']) || !$show_data['sidereel_url']){
            $show_data['sidereel_url'] = $sidereel->grabURL($show_data['title']);
        }
        
        if ($imdb_id){
            mysqlReconnect();
            $existing_episodes = $show->getExistingEpisodes($show_id);
            
            if (count($existing_episodes)){
                if ($auto_only_new){
                    $minimum_season = max(array_keys($existing_episodes));
                } else {
                    $minimum_season = false;
                }
            } else {
                $minimum_season = false;
            }
            
            
            $available_episodes = getAvailableEpisodes($imdb_id, $minimum_season);
            if (count($available_episodes)){
                foreach($available_episodes as $season => $episode_list){
                    foreach($episode_list as $key => $episode){
                        if (isset($existing_episodes[$season]) && in_array($episode,$existing_episodes[$season])){
                            print("already have season {$season}, episode {$episode}\n");
                            continue;
                        } else {
                            print("getting data for season {$season}, episode {$episode}\n");
                            
                            $tvapi_embeds = $tvapi->getEpisodeEmbeds($imdb_id, $season, $episode, $embed_languages);
                            
                            $embeds = array();
                            $duplicate_check = array();
                            
                            if (!$tvapi_embeds || !count($tvapi_embeds)){
                                print("no embeds on TVapi for {$show_data['title']}\t$season\t$episode\n");
                            } else {
                                foreach($tvapi_embeds as $key => $val){
                                    if (!in_array($val['embed'], $duplicate_check)){
                                        $embeds[] = $val;
                                        $duplicate_check[] = $val['embed'];
                                    }
                                }
                            }
                            
                            if (count($embeds) < $embed_limit){
                                $ftvo_embeds = $ftvo->getEmbeds($show_data['title'],$show_id, $season, $episode);
                                if (!$ftvo_embeds || !count($ftvo_embeds)){
                                    print("no embeds on FTVO for {$show_data['title']}\t$season\t$episode\n");
                                } else {
                                    foreach($ftvo_embeds as $key => $val){
                                        if (!in_array($val['embed'], $duplicate_check)){
                                            $embeds[] = $val;
                                            $duplicate_check[] = $val['embed'];
                                        }
                                    }
                                }
                            }
                            
                            if (count($embeds) < $embed_limit){
                                $movie2k_embeds = $movie2k->getEmbeds($show_data['title'], $season, $episode);
                                if (!$movie2k_embeds || !count($movie2k_embeds)){
                                    print("no embeds on movie2k for {$show_data['title']}\t$season\t$episode\n");
                                } else {
                                    foreach($movie2k_embeds as $key => $val){
                                        if (!in_array($val['embed'], $duplicate_check)){
                                            $embeds[] = $val;
                                            $duplicate_check[] = $val['embed'];
                                        }
                                    }
                                }
                            }
                            
                            if (count($embeds)){
                                print("\tfound ".count($embeds)." embed codes\n");
                                
                                /* getting title / description */                            
                                $sidereel_title = $sidereel->sidereelURL($show_data['title'],$show_data['sidereel_url']);
                                $sidereel_link = "http://www.sidereel.com/$sidereel_title/season-$season/episode-$episode"; 
                                
                                $details = $sidereel->getEpisodeDetails($sidereel_link);
                                if ($details && count($details)){
                                    if (!isset($details['title']) || !$details['title']){
                                       $episode_title = "Season $season, Episode $episode";    
                                    } else {
                                        $episode_title = $details['title'];
                                    }
                                    
                                    if (!isset($details['description']) || !$details['description']){
                                        $episode_description = "No description";
                                    } else {
                                        $episode_description = $details['description'];
                                    }
                                } else {
                                    $episode_title = "Season $season, Episode $episode";
                                    $episode_description = "No description";
                                }
                                
                                if ((substr_count(strtolower($episode_title),"season")==0) && (substr_count(strtolower($episode_title),"episode")==0)){
                                    $episode_title = "Season $season, Episode $episode - $episode_title";
                                }
                                
                                /* getting the thumbnail */
                                $episode_thumbnail = $sidereel->getThumbnail($show_data,$season,$episode,$basepath);
                                if (!$episode_thumbnail){
                                    $episode_thumbnail = '';
                                }
                                
                                $episode_data = array();
                                $episode_data['show_id'] = $show_id;
                                $episode_data['title'] = $episode_title;
                                $episode_data['description'] = $episode_description;
                                $episode_data['season'] = $season;
                                $episode_data['episode'] = $episode;
                                $episode_data['thumbnail'] = $episode_thumbnail;
                                
                                mysqlReconnect();
                                $episode_id = $show->saveEpisode($episode_data);
                                
                                foreach($embeds as $key => $embed_data){
                                    mysqlReconnect();
                                    $show->addEmbed($episode_id,$embed_data['embed'], $embed_data['language'], $embed_data['link'], 0);
                                }
                                
                                print("\tepisode saved\n");
                                unset($curl);
                                unset($sidereel);
                                
                                $curl = new Curl();
                                $sidereel = new Sidereel();
                            
                            } else {
                                print("\tcan't find embed codes\n");
                            }
                        }
                    }
                }
            } else {
                print("can't find episode list on IMDB for {$show_data['title']}\n");
            }
        } else {
            print("can't find IMDB id for {$show_data['title']}\n");
        }
    }    
} else {
    print("no shows in the database\n");
}



?>