<?php

set_time_limit(0);

if (php_sapi_name() != 'cli' && !empty($_SERVER['REMOTE_ADDR'])) {
    print("this script can't run from browser");
    exit();
}

require_once("../../vars.php");
require_once("../../includes/curl.php");
require_once("../../includes/ftvo.class.php");
require_once("../../includes/imdb.class.php");
require_once("../../includes/misc.class.php");
require_once("../../includes/movie.class.php");
require_once("../../includes/tvapi.class.php");
require_once("../../includes/settings.class.php");

$ftvo = new FTVO();
$movie = new Movie();
$misc = new Misc();
$curl = new Curl();
$settings = new Settings();
$tvapi = new TVapi();

$embed_languages = $misc->getEmbedLanguages();
$embed_languages = array_keys($embed_languages);
$embed_languages = implode(",",$embed_languages);


function mysqlReconnect(){
    global $dbhost,$dbuser,$dbpass,$dbname;
    
    try{
        mysql_close();
    } catch(Exception $e){
    
    }
    
    mysql_connect($dbhost,$dbuser,$dbpass); mysql_select_db($dbname);
}

$moviefeed_license_key = $settings->getSetting("moviefeed_license_key");
if (!$moviefeed_license_key || empty($moviefeed_license_key)){
    print("no license key found. please enter your key in your admin area\n");
    exit();
} else {
    $res = "OK";
    if ($res!="OK"){
        print("invalid or expired license key. please check your settings in your admin area\n");
        exit();
    }
}

$global_languages = $misc->getLanguages();
$default_language = $settings->getSetting("default_language", true);
if (!$default_language || (is_array($default_language) && empty($default_language))){
    if (array_key_exists("en", $global_languages)){
        $default_language = "en";    
    } else {
        foreach($global_languages as $key => $val){
            $default_language = $key;
            break;
        }
    }    
}


$global_languages = $misc->getLanguages();

if (array_key_exists("en", $global_languages)){
    $categories = $movie->getCategories("en");
} else {
    $categories = $movie->getCategories($default_language);
}

function processMovie($movie_title){
    global $curl, $movie, $misc, $ftvo, $tvapi, $global_languages, $categories, $settings, $basepath, $embed_languages;
    
    $inserted = 0;
    
    preg_match("/\(\d{4}\)/iU",$movie_title,$matches);
    if (count($matches)){
        $year = str_replace(array("(",")"),array("",""),$matches[0]);
        $movie_title = explode($matches[0],$movie_title);
        $movie_title = trim($movie_title[0]);
    } else {
        $year = false;
    }
    
    $imdb = new IMDB(null,$movie_title,$year);
    $imdb_data = $imdb->getDetails();
    
    if (count($imdb_data) && isset($imdb_data['imdb_id'])){
        mysqlReconnect();

        $movie_details = array();
        $movie_details['title'] = array();
        $movie_details['description'] = array();
        
        foreach($global_languages as $lang_code => $lang_name){
            if (isset($imdb_data['summary'])){
                $movie_details['description'][$lang_code] = $imdb_data['summary'];
            } else {
                $movie_details['description'][$lang_code] = '';
            }
            $movie_details['title'][$lang_code] = $movie_title;
        }
        
        $movie_details['perma'] = $movie->makePerma($movie_title);
        $movie_details['imdb_id'] = $imdb_data['imdb_id'];
        $movie_details['thumb'] = "";
        
        if (isset($imdb_data['year']) && $imdb_data['year']){
            $movie_details['year'] = $imdb_data['year'];
        }
        
        if (isset($imdb_data['director']) && $imdb_data['director']){
            $movie_details['director'] = $imdb_data['director'];
        }
        
        if (isset($imdb_data['stars']) && $imdb_data['stars'] && is_array($imdb_data['stars']) && count($imdb_data['stars'])){
            $movie_details['stars'] = $imdb_data['stars'];
        }
        
        if (isset($imdb_data['rating']) && $imdb_data['rating']){
            $movie_details['imdb_rating'] = $imdb_data['rating'];
        }
        
        mysqlReconnect();
        $check = $movie->getByImdb($imdb_data['imdb_id']);
        if (!$check){
            if (isset($imdb_data['image']) && $imdb_data['image']){
                $image_data = $curl->get($imdb_data['image']);
                if ($curl->getHttpCode()>=200 && $curl->getHttpCode()<400){
                    
                    $embeds = $tvapi->getMovieEmbeds($imdb_data['imdb_id'], $embed_languages);
                    if (!$embeds || !count($embeds)){
                        print("no embeds in TVapi for $movie_title\n");             
                        $embeds = $ftvo->getMovieEmbeds($movie_title);
                        if (!count($embeds) && $year){
                            $embeds = $ftvo->getMovieEmbeds($movie_title." (".$year.")");
                        }
                    }
                    
                    if (!$embeds || !count($embeds)){
                        print("no embeds in FTVO for $movie_title\n");
                        continue;
                    }
                    
                    $movie_id = $movie->save($movie_details);
                    $inserted++;
                    file_put_contents("$basepath/thumbs/movie_$movie_id.jpg",$image_data);
                    $movie->updateThumbnail($movie_id,"movie_".$movie_id.".jpg");
                    
                    foreach($embeds as $embed_id => $embed_data){
                        $weight = $misc->getWeight($embed_data['link']);
                        $movie->saveEmbed($movie_id,$embed_data['embed'],"ENG",$weight,$embed_data['link']);
                    }    

                    if (isset($imdb_data['genres']) && is_array($imdb_data['genres']) && count($imdb_data['genres'])){
                        $movie_categories = array();
                        if (count($categories)){
                            foreach($categories as $category_id => $val){
                                foreach($imdb_data['genres'] as $key => $genre){
                                    if (preg_replace("/[^a-z0-9]/","",strtolower($genre))==preg_replace("/[^a-z0-9]/","",strtolower($val['name']))){
                                        $movie_categories[] = $category_id;
                                    }
                                }
                            }
                        }
                        
                        $movie->saveCategories($movie_id,$movie_categories);
                    }                           
                    
                    print("movie saved: $movie_title\n");

                } else {
                    print("can't download image $movie_title\turl:{$imdb_data['image']}\n");
                }
            } else {
                print("no image $movie_title\n");
            }
        } else {
            print("already have $movie_title\n");
        }
           
    } else {
        print("no imdb data $movie_title\n");
    }
    
    return $inserted;
}

$inserted = 0;


$movie_list = $ftvo->getRecentMovies();
if (count($movie_list)){
    foreach($movie_list as $movie_key => $movie_title){
        $inserted = processMovie($movie_title);
    }
} else {
    print("no recent movies found\n");
}

if (!$inserted){
    print("no recent movies found, getting random ones\n");
    $movie_list = $ftvo->getRandomMovies(10);
    
    if (count($movie_list)){
        foreach($movie_list as $movie_key => $movie_title){
            $inserted = processMovie($movie_title);
        }
    } else {
        print("no random movies for some reason\n");
    }
}

?>